@@ -20,6 +20,7 @@
 #include <QStandardPaths>
 
 Q_GLOBAL_STATIC(QStringList, s_requestedBackends)
+static bool s_isFeedback = false;
 
 void DiscoverBackendsFactory::setRequestedBackends(const QStringList &backends)
 {
@@ -46,7 +47,7 @@ QVector<AbstractResourcesBackend *> DiscoverBackendsFactory::backend(const QStri
 
 QVector<AbstractResourcesBackend *> DiscoverBackendsFactory::backendForFile(const QString &libname, const QString &name) const
 {
-    QPluginLoader *loader = new QPluginLoader(QLatin1String("discover/") + libname, ResourcesModel::global());
+    QPluginLoader *loader = new QPluginLoader(QLatin1String("discover/") + libname, QCoreApplication::instance());
 
     // qCDebug(LIBDISCOVER_LOG) << "trying to load plugin:" << loader->fileName();
     AbstractResourcesBackendFactory *f = qobject_cast<AbstractResourcesBackendFactory *>(loader->instance());
@@ -54,7 +55,7 @@ QVector<AbstractResourcesBackend *> DiscoverBackendsFactory::backendForFile(cons
         qCWarning(LIBDISCOVER_LOG) << "error loading" << libname << loader->errorString() << loader->metaData();
         return {};
     }
-    auto instances = f->newInstance(ResourcesModel::global(), name);
+    auto instances = f->newInstance(QCoreApplication::instance(), name);
     if (instances.isEmpty()) {
         qCWarning(LIBDISCOVER_LOG) << "Couldn't find the backend: " << libname << "among" << allBackendNames(false, true);
         return instances;
@@ -67,12 +68,14 @@ QStringList DiscoverBackendsFactory::allBackendNames(bool whitelist, bool allowD
 {
     if (whitelist) {
         QStringList whitelistNames = *s_requestedBackends;
-        if (!whitelistNames.isEmpty())
+        if (s_isFeedback || !whitelistNames.isEmpty())
             return whitelistNames;
     }
 
     QStringList pluginNames;
-    foreach (const QString &dir, QCoreApplication::libraryPaths()) {
+    const auto libraryPaths = QCoreApplication::libraryPaths();
+    qDebug() << "libs" << libraryPaths;
+    for (const QString &dir : libraryPaths) {
         QDirIterator it(dir + QStringLiteral("/discover"), QDir::Files);
         while (it.hasNext()) {
             it.next();
@@ -113,6 +116,12 @@ void DiscoverBackendsFactory::setupCommandLine(QCommandLineParser *parser)
 
 void DiscoverBackendsFactory::processCommandLine(QCommandLineParser *parser, bool test)
 {
+    if (parser->isSet(QStringLiteral("feedback"))) {
+        s_isFeedback = true;
+        s_requestedBackends->clear();
+        return;
+    }
+
     QStringList backends = test //
         ? QStringList{QStringLiteral("dummy-backend")} //
         : parser->value(QStringLiteral("backends")).split(QLatin1Char(','), Qt::SkipEmptyParts);
