@@ -59,7 +59,7 @@ void SnapTransaction::finishTransaction()
         p->setProgram(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR "/discover/SnapMacaroonDialog"));
         p->start();
 
-        connect(p, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, [this, p](int code, QProcess::ExitStatus status) {
+        connect(p, &QProcess::finished, this, [this, p](int code, QProcess::ExitStatus status) {
             p->deleteLater();
             if (code != 0) {
                 qWarning() << "login failed... code:" << code << status << p->readAll();
@@ -80,9 +80,9 @@ void SnapTransaction::finishTransaction()
     }
         return;
     default:
-        setStatus(DoneWithErrorStatus);
-        qDebug() << "snap error" << m_request << m_request->error() << m_request->errorString();
+        qDebug() << "snap error" << m_request.get() << m_request->error() << m_request->errorString();
         Q_EMIT passiveMessage(m_request->errorString());
+        setStatus(DoneWithErrorStatus);
         break;
     }
 }
